==> chaosmesh-model-6.8.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/TimespecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TimespecFluent<A extends TimespecFluent<A>> extends BaseFluent<A>{
  public TimespecFluent() {
  }
  public TimespecFluent(Timespec instance) {
    instance = (instance != null ? instance : new Timespec());

    if (instance != null) {
      this.withNsec(instance.getNsec());
      this.withSec(instance.getSec());
      this.withNsec(instance.getNsec());
      this.withSec(instance.getSec());
    }
  }
  private Long nsec;
  private Long sec;
  public Long getNsec() {
    return this.nsec;
  }
  public A withNsec(Long nsec) {
    this.nsec=nsec; return (A) this;
  }
  public boolean hasNsec() {
    return this.nsec != null;
  }
  public Long getSec() {
    return this.sec;
  }
  public A withSec(Long sec) {
    this.sec=sec; return (A) this;
  }
  public boolean hasSec() {
    return this.sec != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TimespecFluent that = (TimespecFluent) o;
    if (!java.util.Objects.equals(nsec, that.nsec)) return false;

    if (!java.util.Objects.equals(sec, that.sec)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(nsec,  sec,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (nsec != null) { sb.append("nsec:"); sb.append(nsec + ","); }
    if (sec != null) { sb.append("sec:"); sb.append(sec); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/TimespecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class TimespecFluent<A extends TimespecFluent<A>> extends BaseFluent<A>{
  public TimespecFluent() {
  }
  
  public TimespecFluent(Timespec instance) {
    this.copyInstance(instance);
  }
  private Long nsec;
  private Long sec;
  
  protected void copyInstance(Timespec instance) {
    instance = (instance != null ? instance : new Timespec());
  
    if (instance != null) {
        this.withNsec(instance.getNsec());
        this.withSec(instance.getSec());
        this.withNsec(instance.getNsec());
        this.withSec(instance.getSec());
      }
  }
  
  public Long getNsec() {
    return this.nsec;
  }
  
  public A withNsec(Long nsec) {
    this.nsec=nsec; return (A) this;
  }
  
  public boolean hasNsec() {
    return this.nsec != null;
  }
  
  public Long getSec() {
    return this.sec;
  }
  
  public A withSec(Long sec) {
    this.sec=sec; return (A) this;
  }
  
  public boolean hasSec() {
    return this.sec != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TimespecFluent that = (TimespecFluent) o;
    if (!java.util.Objects.equals(nsec, that.nsec)) return false;
  
    if (!java.util.Objects.equals(sec, that.sec)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(nsec,  sec,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (nsec != null) { sb.append("nsec:"); sb.append(nsec + ","); }
    if (sec != null) { sb.append("sec:"); sb.append(sec); }
    sb.append("}");
    return sb.toString();
  }
  

}
